@@ -80,7 +80,7 @@ class ConfigManager:
         try:
             self.global_config = yaml.load(open(self.global_config_file_path, 'r', encoding='utf-8'), yaml.SafeLoader)
         except:
-            raise DSOException(MESSAGES['InvalidDSOConfigurationFile'])
+            raise DSOException(CLI_MESSAGES['InvalidDSOConfigurationFile'])
 
         self.update_merged_config()
 
@@ -92,7 +92,7 @@ class ConfigManager:
         if not os.path.exists(self.local_config_file_path):
             self.local_config = {}
             if show_warnings:
-                Logger.warn(MESSAGES['NoDSOConfigFound'])
+                Logger.warn(CLI_MESSAGES['NoDSOConfigFound'])
             return
 
         Logger.debug(f"Local DSO configuration found: path={self.local_config_file_path}")
@@ -100,7 +100,7 @@ class ConfigManager:
         try:
             self.local_config = yaml.load(open(self.local_config_file_path, 'r', encoding='utf-8'), yaml.SafeLoader)
         except:
-            raise DSOException(MESSAGES['InvalidDSOConfigurationFile'])
+            raise DSOException(CLI_MESSAGES['InvalidDSOConfigurationFile'])
 
         self.update_merged_config()
 
@@ -119,7 +119,7 @@ class ConfigManager:
             try:
                 config = yaml.load(open(configFile, 'r', encoding='utf-8'), yaml.SafeLoader)
             except:
-                raise DSOException(MESSAGES['InvalidDSOConfigurationFile'])
+                raise DSOException(CLI_MESSAGES['InvalidDSOConfigurationFile'])
             
             self.inherited_config = merge_dicts(config, self.inherited_config)
 
@@ -142,7 +142,7 @@ class ConfigManager:
                         Logger.warn(f"DSO configuration '{key}' was overriden from '{old}' to '{value or 'default'}'.")
                     set_dict_value(self.overriden_config, key.split('.'), value)
             except:
-                raise DSOException(MESSAGES['InvalidConfigOverrides'])
+                raise DSOException(CLI_MESSAGES['InvalidDSOConfigOverrides'])
 
         self.update_merged_config()
 
@@ -158,9 +158,9 @@ class ConfigManager:
     def check_version(self):
         if not int(self.merged_config['version']) == default_config['version']:
             if int(self.merged_config['version']) > default_config['version']:
-                Logger.warn(MESSAGES['DSOConfigNewer'].format(default_config['version'], self.merged_config['version']))
+                Logger.warn(CLI_MESSAGES['DSOConfigNewer'].format(default_config['version'], self.merged_config['version']))
             else:
-                Logger.warn(MESSAGES['DSOConfigOlder'].format(default_config['version'], self.merged_config['version']))
+                Logger.warn(CLI_MESSAGES['DSOConfigOlder'].format(default_config['version'], self.merged_config['version']))
 
 
     def get_provider_default_spec(self, provider_id):
@@ -229,7 +229,7 @@ class ConfigManager:
         try:
             result = self.merged_config['parameter']['provider']['id']
         except KeyError:
-            raise DSOException(MESSAGES['ProviderNotSet'].format('Parameter'))
+            raise DSOException(CLI_MESSAGES['ProviderNotSet'].format('Parameter'))
         return result
 
     @property
@@ -237,7 +237,7 @@ class ConfigManager:
         try:
             result = self.merged_config['secret']['provider']['id']
         except KeyError:
-            raise DSOException(MESSAGES['ProviderNotSet'].format('Secret'))
+            raise DSOException(CLI_MESSAGES['ProviderNotSet'].format('Secret'))
         return result
 
     @property
@@ -245,14 +245,14 @@ class ConfigManager:
         try:
             result = self.merged_config['template']['provider']['id']
         except KeyError:
-            raise DSOException(MESSAGES['ProviderNotSet'].format('Template'))
+            raise DSOException(CLI_MESSAGES['ProviderNotSet'].format('Template'))
         return result
 
     def parameter_spec(self, key=None):
         try:
             result = self.merged_config['parameter']['provider']['spec']
         except KeyError:
-            raise DSOException(MESSAGES['ProviderNotSet'].format('Parameter'))
+            raise DSOException(CLI_MESSAGES['ProviderNotSet'].format('Parameter'))
         if not key:
             return result
         elif key in result:
@@ -264,7 +264,7 @@ class ConfigManager:
         try:
             result = self.merged_config['secret']['provider']['spec']
         except KeyError:
-            raise DSOException(MESSAGES['ProviderNotSet'].format('Secret'))
+            raise DSOException(CLI_MESSAGES['ProviderNotSet'].format('Secret'))
         if not key:
             return result
         elif key in result:
@@ -276,7 +276,7 @@ class ConfigManager:
         try:
             result = self.merged_config['template']['provider']['spec']
         except KeyError:
-            raise DSOException(MESSAGES['ProviderNotSet'].format('Template'))
+            raise DSOException(CLI_MESSAGES['ProviderNotSet'].format('Template'))
         if not key:
             return result
         elif key in result:
@@ -285,19 +285,20 @@ class ConfigManager:
             return None
 
     def get_template_render_path(self, key=None):
-        result = get_dict_item(self.local_config, ['template', 'render'])
+        result = get_dict_item(self.local_config, ['template', 'render']) or {}
         if not key:
             return result
         else:
             return {x:result[x] for x in result if x==key}
 
     def register_template_custom_render_path(self, key, render_path):
-        result = get_dict_item(self.local_config, ['template', 'render'])
+        result = get_dict_item(self.local_config, ['template', 'render']) or {}
         # if os.path.isabs(render_path):
-        #     raise DSOException(MESSAGES['AbsTemplateRenderPath'].format(render_path))
+        #     raise DSOException(CLI_MESSAGES['AbsTemplateRenderPath'].format(render_path))
         if os.path.isdir(render_path):
-            raise DSOException(MESSAGES['InvalidRenderPathExistingDir'].format(render_path))
+            raise DSOException(CLI_MESSAGES['InvalidRenderPathExistingDir'].format(render_path))
         result[key] = render_path
+        self.local_config['template']['render'] = result
         self.flush_local_config()
 
     def unregister_template_custom_render_path(self, key):
